@@ -13,10 +13,8 @@
 #include <math.h>
 #include <limits.h>
 
-#ifndef _MSC_VER
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
-#endif
 
 /*-------------------------------------------------------------------------*/
 /* Local includes							   */
@@ -447,13 +445,8 @@ XPoint UGetCursor()
    /* Don't use areastruct.areawin;  if called from inside an object	*/
    /* (e.g., "here" in a Tcl expression), areastruct.areawin will be	*/
    /* an off-screen pixmap, and cause a crash.				*/
-#ifndef _MSC_VER
    XQueryPointer(dpy, Tk_WindowId(areastruct.area), &nullwin, &nullwin,
 	&nullint, &nullint, &xpos, &ypos, &nullui);
-#else
-   XQueryPointer_TkW32(dpy, Tk_WindowId(areastruct.area), &nullwin, &nullwin,
-	&nullint, &nullint, &xpos, &ypos, &nullui);
-#endif
 #else
    XQueryPointer(dpy, areastruct.areawin, &nullwin, &nullwin, &nullint,
 	&nullint, &xpos, &ypos, &nullui);
@@ -1393,18 +1386,11 @@ void zoomview(xcWidget w, caddr_t clientdata, caddr_t calldata)
 	 eventmode == MOVE_MODE || eventmode == CATALOG_MODE ||
 	eventmode == FONTCAT_MODE || eventmode == EFONTCAT_MODE) {
 
-#ifdef USE_WIN32_COM
-      float scale = *(areastruct.vscale);
-#endif
       centerview(areastruct.topinstance);
       invalidate_graphics(topobject);
       areastruct.lastbackground = NULL;
       renderbackground();
       refresh(NULL, NULL, NULL);
-#ifdef USE_WIN32_COM
-      if (*(areastruct.vscale) != scale)
-         win32_fire_event(ZoomChanged);
-#endif
    }
 }
 
@@ -1849,11 +1835,11 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
       if (style & (DASHED | DOTTED)) {
          SetDashes(dpy, areastruct.gc, 0, dashstring, 2);
          SetLineAttributes(dpy, areastruct.gc, tmpwidth, LineOnOffDash,
-		CapButt, JoinMiter);
+		CapButt, JoinBevel);
       }
       else
          SetLineAttributes(dpy, areastruct.gc, tmpwidth, LineSolid,
-		(style & SQUARECAP) ? CapProjecting : CapRound, JoinMiter);
+		CapRound, JoinBevel);
 
       /* draw the spline and close off if so specified */
       DrawLines(dpy, areastruct.areawin, areastruct.gc, pathlist,
@@ -1971,7 +1957,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
    int		defaultcolor = passcolor;
    int		curcolor = passcolor;
    int		thispart;
-   XPoint 	bboxin[2], bboxout[2];
+   XPoint 	bboxin, bboxout[2];
    u_char	xm, ym;
    objectptr	theobject = theinstance->thisobject;
 
@@ -1988,13 +1974,10 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 
    /* do a quick test for intersection with the display window */
 
-   bboxin[0].x = theobject->bbox.lowerleft.x;
-   bboxin[0].y = theobject->bbox.lowerleft.y;
-   bboxin[1].x = theobject->bbox.lowerleft.x + theobject->bbox.width;
-   bboxin[1].y = theobject->bbox.lowerleft.y + theobject->bbox.height; 
-   if (level == 0)
-      extendschembbox(theinstance, &(bboxin[0]), &(bboxin[1]));
-   UTransformbyCTM(DCTM, bboxin, bboxout, 2);
+   UTransformbyCTM(DCTM, &(theobject->bbox.lowerleft), &(bboxout[0]), 1);
+   bboxin.x = theobject->bbox.lowerleft.x + theobject->bbox.width;
+   bboxin.y = theobject->bbox.lowerleft.y + theobject->bbox.height; 
+   UTransformbyCTM(DCTM, &bboxin, &(bboxout[1]), 1);
 
    xm = (bboxout[0].x < bboxout[1].x) ? 0 : 1;  
    ym = (bboxout[0].y < bboxout[1].y) ? 0 : 1;  
@@ -2200,12 +2183,8 @@ void TopDoLatex()
    fprintf(f, "\\def\\topbox#1{\\raisebox{-\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\def\\midbox#1{\\raisebox{-0.5\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\begin{flushleft}\n");
-
-   filename[strlen(filename) - 4] = '\0';
-   if (strchr(filename, '.') == NULL)
-      sprintf(filename + strlen(filename), ".ps");
-
-   fprintf(f, "\\epsfig{file=%s}\\\\\n", filename);
+   fprintf(f, "\\epsfig{file=%s.ps}\\\\\n",
+		xobjs.pagelist[areastruct.page]->filename);
 
    psscale = getpsscale(xobjs.pagelist[areastruct.page]->outscale,
 		areastruct.page);
