@@ -13,17 +13,12 @@
 #include <ctype.h>	 /* for tolower(), toupper() */
 #include <math.h>
 
-#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
-#endif
-
-#if !defined(XC_WIN32) || defined(TCL_WRAPPER)
 #define  XK_MISCELLANY
 #define  XK_LATIN1
 #define  XK_XKB_KEYS
 #include <X11/keysymdef.h>
-#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -361,11 +356,7 @@ char *key_to_string(int keywstate)
    KeySym ks = keywstate & 0xffff;
    int kmod = keywstate >> 16;
 
-#if defined(XC_WIN32) && defined(TCL_WRAPPER)
-   if (ks != NoSymbol) str = XKeysymToString_TkW32(ks);
-#else
    if (ks != NoSymbol) str = XKeysymToString(ks);
-#endif
 
    kptr = (char *)malloc(32);
    kptr[0] = '\0';
@@ -554,15 +545,15 @@ void default_keybindings()
    add_vbinding(XK_9, XCF_Page, 9);
    add_vbinding(XK_0, XCF_Page, 10);
 
-   add_vbinding(XK_KP_1, XCF_Justify, 0);
-   add_vbinding(XK_KP_2, XCF_Justify, 1);
-   add_vbinding(XK_KP_3, XCF_Justify, 2);
-   add_vbinding(XK_KP_4, XCF_Justify, 3);
-   add_vbinding(XK_KP_5, XCF_Justify, 4);
-   add_vbinding(XK_KP_6, XCF_Justify, 5);
-   add_vbinding(XK_KP_7, XCF_Justify, 6);
-   add_vbinding(XK_KP_8, XCF_Justify, 7);
-   add_vbinding(XK_KP_9, XCF_Justify, 8);
+   add_vbinding(SHIFT | XK_KP_1, XCF_Justify, 0);
+   add_vbinding(SHIFT | XK_KP_2, XCF_Justify, 1);
+   add_vbinding(SHIFT | XK_KP_3, XCF_Justify, 2);
+   add_vbinding(SHIFT | XK_KP_4, XCF_Justify, 3);
+   add_vbinding(SHIFT | XK_KP_5, XCF_Justify, 4);
+   add_vbinding(SHIFT | XK_KP_6, XCF_Justify, 5);
+   add_vbinding(SHIFT | XK_KP_7, XCF_Justify, 6);
+   add_vbinding(SHIFT | XK_KP_8, XCF_Justify, 7);
+   add_vbinding(SHIFT | XK_KP_9, XCF_Justify, 8);
 
    add_vbinding(XK_KP_End, XCF_Justify, 0);
    add_vbinding(XK_KP_Down, XCF_Justify, 1);
@@ -717,15 +708,10 @@ void default_keybindings()
    }
    else {
       add_binding(BUTTON2, XCF_Text_Return);
-      add_binding(SHIFT | BUTTON1, XCF_Text_Return);
       add_binding(BUTTON2, XCF_Select);
-      add_binding(SHIFT | BUTTON1, XCF_Select);
       add_binding(HOLD | BUTTON2, XCF_SelectBox);
-      add_binding(SHIFT | HOLD | BUTTON1, XCF_SelectBox);
       add_binding(BUTTON2, XCF_Finish_Element);
-      add_binding(SHIFT | BUTTON1, XCF_Finish_Element);
       add_binding(BUTTON2, XCF_Finish_Copy);
-      add_binding(SHIFT | BUTTON1, XCF_Finish_Copy);
       add_binding(BUTTON3, XCF_Cancel_Last);
       add_binding(BUTTON3, XCF_Cancel);
    }
