@@ -678,6 +678,49 @@ void collectsubschems(int toppage)
    free((char *)pagelist);
 }
 
+/*--------------------------------------------------------*/
+/* Copy label to corresponding schematic/symbol		  */
+/*--------------------------------------------------------*/
+
+void copypinlabel(labelptr pinlab)
+{
+   labelptr *newlabel, tlabel;
+   genericptr *tgen;
+   objectptr schemobj = topobject->symschem;
+
+   if (areastruct.schemon && schemobj != NULL && (pinlab->pin == LOCAL)) {
+
+      /* If this pin already exists, don't copy it */
+
+      for (tgen = schemobj->plist; tgen < schemobj->plist + schemobj->parts;
+		tgen++) {
+         if (IS_LABEL(*tgen)) {
+	    tlabel = TOLABEL(tgen);
+	    if (!stringcomp(tlabel->string, pinlab->string)) return;
+         }
+      }
+
+      NEW_LABEL(newlabel, schemobj);
+      (*newlabel)->pin = pinlab->pin;
+      (*newlabel)->rotation = pinlab->rotation;
+      (*newlabel)->justify = pinlab->justify;
+      (*newlabel)->color = pinlab->color;
+      (*newlabel)->scale = pinlab->scale;
+      (*newlabel)->string = stringcopy(pinlab->string);
+      (*newlabel)->passed = NULL;
+
+      /* place label just outside bounding box, then recompute bbox */
+
+      (*newlabel)->position.x = schemobj->bbox.lowerleft.x + (schemobj->bbox.width >> 1);
+      (*newlabel)->position.y = schemobj->bbox.lowerleft.y - TEXTHEIGHT
+	   * (*newlabel)->scale;
+      schemobj->parts++;
+      incr_changes(schemobj);
+      invalidate_netlist(schemobj);
+      singlebbox(ENDPART);
+   }
+}
+
 /*-------------------------------------------------------*/
 /* Check if top-level page is the same name as a library */
 /* object; if so, connect it.				 */
